@@ -29,18 +29,13 @@
 #' https://doi.org/10.1109/72.761722
 #'
 #' @examples
+#' if(requireNamespace("fastICA", quietly = TRUE)) {
+#'
 #' dat <- loadDataSet("3D S Curve")
+#' emb <- embed(dat, "FastICA", ndim = 2)
+#' plot(getData(getDimRedData(emb)))
 #'
-#' ## use the S4 Class directly:
-#' fastica <- FastICA()
-#' emb <- fastica@fun(dat, pars = list(ndim = 2))
-#'
-#' ## simpler, use embed():
-#' emb2 <- embed(dat, "FastICA", ndim = 2)
-#'
-#'
-#' plot(emb@data@data)
-#'
+#' }
 #' @include dimRedResult-class.R
 #' @include dimRedMethod-class.R
 #' @family dimensionality reduction methods
@@ -117,5 +112,6 @@ FastICA <- setClass(
             method       = "FastICA",
             pars         = pars
         ))
-    })
+        },
+      requires = c("fastICA"))
 )
