@@ -26,17 +26,13 @@
 #' 5591-5596. doi:10.1073/pnas.1031596100
 #'
 #' @examples
+#' if(requireNamespace(c("RSpectra", "Matrix", "RANN"), quietly = TRUE)) {
+#'
 #' dat <- loadDataSet("3D S Curve", n = 300)
-#'
-#' ## directy use the S4 class:
-#' hlle <- HLLE()
-#' emb <- hlle@fun(dat, hlle@stdpars)
-#'
-#' ## using embed():
-#' emb2 <- embed(dat, "HLLE", knn = 45)
-#'
+#' emb <- embed(dat, "HLLE", knn = 15)
 #' plot(emb, type = "2vars")
-#' plot(emb2, type = "2vars")
+#'
+#' }
 #'
 #' @include dimRedResult-class.R
 #' @include dimRedMethod-class.R
@@ -125,5 +121,6 @@ HLLE <- setClass(
             method       = "HLLE",
             pars         = pars
         ))
-    })
+        },
+        requires = c("RSpectra", "Matrix", "RANN"))
 )
