@@ -37,17 +37,14 @@
 #'
 #' @examples
 #' \dontrun{
+#' if(requireNamespace("kernlab", quietly = TRUE)) {
+#'
 #' dat <- loadDataSet("3D S Curve")
-#'
-#' ## use the S4 class directly:
-#' kpca <- kPCA()
-#' emb <- kpca@fun(dat, kpca@stdpars)
-#'
-#' ## simpler, use embed():
-#' emb2 <- embed(dat, "kPCA")
-#'
+#' emb <- embed(dat, "kPCA")
 #' plot(emb, type = "2vars")
 #' }
+#'
+#' }
 #' @include dimRedResult-class.R
 #' @include dimRedMethod-class.R
 #' @family dimensionality reduction methods
@@ -130,7 +127,8 @@ kPCA <- setClass(
                 pars         = pars
             )
         )
-    })
+        },
+      requires = c("kernlab"))
 )
 
 
